@@ -27,7 +27,7 @@
 #include "xfburn-adding-progress.h"
 #include "xfburn-utils.h"
 
-#define XFBURN_ADDING_PROGRESS_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_ADDING_PROGRESS, XfburnAddingProgressPrivate))
+#define XFBURN_ADDING_PROGRESS_GET_PRIVATE(obj) (xfburn_adding_progress_get_instance_private (obj))
 
 enum {
   ADDING_DONE,
@@ -42,11 +42,10 @@ typedef struct
 } XfburnAddingProgressPrivate;
 
 /* prototypes */
-static void xfburn_adding_progress_class_init (XfburnAddingProgressClass *);
-static void xfburn_adding_progress_init (XfburnAddingProgress *);
+G_DEFINE_TYPE_WITH_PRIVATE(XfburnAddingProgress, xfburn_adding_progress, GTK_TYPE_WINDOW)
 static void xfburn_adding_progress_finalize (GObject * object);
-static gboolean cb_delete (GtkWidget *widget, GdkEvent *event, gpointer data);
-static gboolean cb_cancel (GtkWidget *widget, GdkEvent *event, gpointer data);
+static gboolean cb_delete (XfburnAddingProgress *widget, GdkEvent *event, gpointer data);
+static gboolean cb_cancel (XfburnAddingProgress *widget, GdkEvent *event, gpointer data);
 
 /* globals */
 static GtkWindowClass *parent_class = NULL;
@@ -56,43 +55,15 @@ static guint signals[LAST_SIGNAL];
 /* XfburnAddingProgress class */
 /******************************/
 
-GType
-xfburn_adding_progress_get_type (void)
-{
-  static GType adding_progress_type = 0;
-
-  if (!adding_progress_type)
-    {
-      static const GTypeInfo adding_progress_info = {
-        sizeof (XfburnAddingProgressClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) xfburn_adding_progress_class_init,
-        NULL,
-        NULL,
-        sizeof (XfburnAddingProgress),
-        0,
-        (GInstanceInitFunc) xfburn_adding_progress_init,
-        NULL
-      };
-
-      adding_progress_type = g_type_register_static (GTK_TYPE_WINDOW, "XfburnAddingProgress", &adding_progress_info, 0);
-    }
-
-  return adding_progress_type;
-}
-
 static void
 xfburn_adding_progress_class_init (XfburnAddingProgressClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (XfburnAddingProgressPrivate));
-
   parent_class = g_type_class_peek_parent (klass);
 
   object_class->finalize = xfburn_adding_progress_finalize;
-  
+
   signals[ADDING_DONE] = g_signal_new ("adding-done", XFBURN_TYPE_ADDING_PROGRESS, G_SIGNAL_ACTION,
                                           G_STRUCT_OFFSET (XfburnAddingProgressClass, adding_done),
                                           NULL, NULL, g_cclosure_marshal_VOID__VOID,
@@ -107,15 +78,15 @@ xfburn_adding_progress_init (XfburnAddingProgress * win)
   
   gtk_window_set_resizable (GTK_WINDOW (win), FALSE);
 
-  gtk_window_set_icon_name (GTK_WINDOW (win), GTK_STOCK_ADD);
+  gtk_window_set_icon_name (GTK_WINDOW (win), "list-add");
   gtk_window_set_destroy_with_parent (GTK_WINDOW (win), TRUE);
   gtk_window_set_title (GTK_WINDOW (win), _("Adding files to the composition"));
   
-  vbox = gtk_vbox_new (FALSE, 5);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 5);
   gtk_widget_show (vbox);
   gtk_container_add (GTK_CONTAINER (win), vbox);
     
-  priv->progress_bar = gtk_progress_bar_new ();
+  priv->progress_bar = xfburn_create_progress_bar (NULL);
   gtk_progress_bar_set_pulse_step (GTK_PROGRESS_BAR (priv->progress_bar), 0.01);
   gtk_widget_show (priv->progress_bar);
   gtk_box_pack_start (GTK_BOX (vbox), priv->progress_bar, TRUE, TRUE, BORDER);
@@ -142,7 +113,7 @@ xfburn_adding_progress_finalize (GObject * object)
 /* internals */
 
 static gboolean
-cb_delete (GtkWidget *widget, GdkEvent *event, gpointer data)
+cb_delete (XfburnAddingProgress *widget, GdkEvent *event, gpointer data)
 {
   XfburnAddingProgressPrivate *priv = XFBURN_ADDING_PROGRESS_GET_PRIVATE (widget);
   priv->aborted = TRUE;
@@ -151,7 +122,7 @@ cb_delete (GtkWidget *widget, GdkEvent *event, gpointer data)
 }
 
 static gboolean
-cb_cancel (GtkWidget *widget, GdkEvent *event, gpointer data)
+cb_cancel (XfburnAddingProgress *widget, GdkEvent *event, gpointer data)
 {
   XfburnAddingProgressPrivate *priv = XFBURN_ADDING_PROGRESS_GET_PRIVATE (data);
   priv->aborted = TRUE;
