@@ -291,18 +291,7 @@ xfburn_audio_composition_init (XfburnAudioComposition * composition)
   GSimpleAction *action = NULL;
   GdkScreen *screen;
   GtkIconTheme *icon_theme;
-
-#if 0 /* CDTEXT */
-  const gchar ui_string[] = "<ui> <popup name=\"popup-menu\">"
-    "<menuitem action=\"rename-artist\"/>" "<menuitem action=\"rename-title\"/>" "<menuitem action=\"remove-file\"/>" "</popup></ui>";
-#else
-  // const gchar ui_string[] = "<ui> <popup name=\"popup-menu\"> <menuitem action=\"remove-file\"/>" "</popup></ui>";
-  const gchar ui_string[] = "<interface><menu id=\"popup-menu\">"
-    "<section>"
-    "<item><attribute name=\"label\">Remove</attribute><attribute name=\"action\">win.remove-file</attribute></item>"
-    "</section>"
-    "</menu></interface>";
-#endif /* CDTEXT */
+  gchar *popup_ui;
 
   GtkTargetEntry gte_src[] =  { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, AUDIO_COMPOSITION_DND_TARGET_INSIDE } };
   GtkTargetEntry gte_dest[] = { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, AUDIO_COMPOSITION_DND_TARGET_INSIDE },
@@ -322,6 +311,9 @@ xfburn_audio_composition_init (XfburnAudioComposition * composition)
   screen = gtk_widget_get_screen (GTK_WIDGET (composition));
   icon_theme = gtk_icon_theme_get_for_screen (screen);
 
+  xfce_resource_push_path (XFCE_RESOURCE_DATA, DATADIR);
+  popup_ui = xfce_resource_lookup (XFCE_RESOURCE_DATA, "xfburn/xfburn-popup-menus.ui");
+
   gtk_icon_size_lookup (GTK_ICON_SIZE_SMALL_TOOLBAR, &x, &y);
   if (!icon_directory)
     icon_directory = gtk_icon_theme_load_icon (icon_theme, "folder", x, 0, NULL);
@@ -334,7 +326,7 @@ xfburn_audio_composition_init (XfburnAudioComposition * composition)
                                 GTK_WIDGET (composition));
   priv->ui_manager = gtk_builder_new ();
   gtk_builder_set_translation_domain (priv->ui_manager, GETTEXT_PACKAGE);
-  gtk_builder_add_from_string (priv->ui_manager, ui_string, -1, NULL);
+  gtk_builder_add_from_file(priv->ui_manager, popup_ui, NULL);
   gtk_widget_insert_action_group(GTK_WIDGET (composition), "win", G_ACTION_GROUP (priv->action_group));
 
   hbox_toolbar = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
@@ -363,20 +355,20 @@ xfburn_audio_composition_init (XfburnAudioComposition * composition)
   gtk_widget_insert_action_group (priv->toolbar, "win", G_ACTION_GROUP (priv->action_group));
 
   xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbar),
-    "list-add", "Add", "win.add-file", _("Add the selected file(s) to the composition"));
+    "list-add", _("Add"), "win.add-file", _("Add the selected file(s) to the composition"));
 
   gtk_toolbar_insert (GTK_TOOLBAR (priv->toolbar), gtk_separator_tool_item_new(), -1);
 
   xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbar),
-    "list-remove", "Remove", "win.remove-file", _("Remove the selected file(s) from the composition"));
+    "list-remove", _("Remove"), "win.remove-file", _("Remove the selected file(s) from the composition"));
   xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbar),
-    "edit-clear", "Clear", "win.clear", _("Clear the content of the composition"));
+    "edit-clear", _("Clear"), "win.clear", _("Clear the content of the composition"));
 
   gtk_toolbar_insert (GTK_TOOLBAR (priv->toolbar), gtk_separator_tool_item_new(), -1);
 
 #ifdef HAVE_GST
   xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbar),
-    "help-about", "gstreamer", "win.transcoder-info", _("What files can get burned to an audio CD?"));
+    "help-about", _("gstreamer"), "win.transcoder-info", _("What files can get burned to an audio CD?"));
 #endif
   gtk_box_pack_start (GTK_BOX (hbox_toolbar), priv->toolbar, TRUE, TRUE, 0);
   gtk_widget_show_all (priv->toolbar);
@@ -662,7 +654,11 @@ cb_treeview_button_pressed (GtkTreeView * treeview, GdkEventButton * event, Xfbu
       gtk_tree_path_free (path);
     }
 
-    model = G_MENU_MODEL (gtk_builder_get_object (priv->ui_manager, "popup-menu"));
+#if 0 /* CDTEXT */
+    model = G_MENU_MODEL (gtk_builder_get_object (priv->ui_manager, "audio-cdtext-popup-menu"));
+#else
+    model = G_MENU_MODEL (gtk_builder_get_object (priv->ui_manager, "audio-popup-menu"));
+#endif /* CDTEXT */
     menu_popup = gtk_menu_new_from_model (model);
     gtk_widget_insert_action_group(GTK_WIDGET(menu_popup), "win", G_ACTION_GROUP (priv->action_group));
     menuitem_remove = GTK_WIDGET (gtk_container_get_children (GTK_CONTAINER (menu_popup))->data);
