@@ -210,7 +210,7 @@ xfburn_blank_dialog_init (XfburnBlankDialog * obj)
   gtk_box_pack_start (GTK_BOX (vbox), priv->check_eject, FALSE, FALSE, BORDER);
 
   /* action buttons */
-  button = gtk_button_new_with_mnemonic ("_Cancel");
+  button = gtk_button_new_with_mnemonic (_("_Cancel"));
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_CANCEL);
 
