@@ -27,19 +27,19 @@
 #include <fcntl.h>
 
 #include <gtk/gtk.h>
+#include <exo/exo.h>
 
 #include "xfburn-global.h"
 #include "xfburn-utils.h"
 #include "xfburn-progress-dialog.h"
 #include "xfburn-device-box.h"
-#include "xfburn-stock.h"
 #include "xfburn-settings.h"
 #include "xfburn-main.h"
 
 #include "xfburn-burn-image-dialog.h"
 #include "xfburn-perform-burn.h"
 
-#define XFBURN_BURN_IMAGE_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_BURN_IMAGE_DIALOG, XfburnBurnImageDialogPrivate))
+#define XFBURN_BURN_IMAGE_DIALOG_GET_PRIVATE(obj) (xfburn_burn_image_dialog_get_instance_private (XFBURN_BURN_IMAGE_DIALOG (obj)))
 
 typedef struct {
   GtkWidget *dialog_progress;
@@ -65,7 +65,7 @@ typedef struct
 {
   GtkWidget *chooser_image;
   GtkWidget *image_label;
-  
+
   GtkWidget *device_box;
 
   GtkWidget *check_eject;
@@ -86,8 +86,6 @@ typedef struct
 static gchar * last_file = NULL;
 
 /* prototypes */
-static void xfburn_burn_image_dialog_class_init (XfburnBurnImageDialogClass * klass);
-static void xfburn_burn_image_dialog_init (XfburnBurnImageDialog * sp);
 static void xfburn_burn_image_dialog_finalize (GObject *object);
 
 /* internal prototypes */
@@ -103,45 +101,20 @@ static void cb_clicked_ok (GtkButton * button, gpointer user_data);
 static void free_params (ThreadBurnIsoParams *params);
 static gboolean prepare_params (ThreadBurnIsoParams *params, struct burn_drive *drive, gchar **failure_msg);
 static gboolean create_disc (ThreadBurnIsoParams *params, gchar **failure_msg);
-static void thread_burn_iso (ThreadBurnIsoParams * params);
+static void* thread_burn_iso (ThreadBurnIsoParams * params);
 
 /*********************/
 /* class declaration */
 /*********************/
 static XfceTitledDialogClass *parent_class = NULL;
 
-GType
-xfburn_burn_image_dialog_get_type (void)
-{
-  static GType type = 0;
-
-  if (type == 0) {
-    static const GTypeInfo our_info = {
-      sizeof (XfburnBurnImageDialogClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_burn_image_dialog_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnBurnImageDialog),
-      0,
-      (GInstanceInitFunc) xfburn_burn_image_dialog_init,
-      NULL
-    };
-
-    type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnBurnImageDialog", &our_info, 0);
-  }
-
-  return type;
-}
+G_DEFINE_TYPE_WITH_PRIVATE(XfburnBurnImageDialog,xfburn_burn_image_dialog, XFCE_TYPE_TITLED_DIALOG);
 
 static void
 xfburn_burn_image_dialog_class_init (XfburnBurnImageDialogClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (XfburnBurnImageDialogPrivate));
-
   parent_class = g_type_class_peek_parent (klass);
 
   object_class->finalize     = xfburn_burn_image_dialog_finalize;
@@ -150,22 +123,24 @@ xfburn_burn_image_dialog_class_init (XfburnBurnImageDialogClass * klass)
 static void
 xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
 {
-  GtkBox *box = GTK_BOX (GTK_DIALOG (obj)->vbox);
+  GtkBox *box = GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG (obj)));
   XfburnBurnImageDialogPrivate *priv = XFBURN_BURN_IMAGE_DIALOG_GET_PRIVATE (obj);
-  
+
   GdkPixbuf *icon = NULL;
   GtkFileFilter *filter;
   GtkWidget *frame;
   GtkWidget *vbox;
   GtkWidget *button;
+  gint x,y;
   XfburnDevice *device;
 
   gtk_window_set_title (GTK_WINDOW (obj), _("Burn image"));
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
-  icon = gtk_widget_render_icon (GTK_WIDGET (obj), XFBURN_STOCK_BURN_CD, GTK_ICON_SIZE_DIALOG, NULL);
+  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
+  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "stock_xfburn", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
   gtk_window_set_icon (GTK_WINDOW (obj), icon);
   g_object_unref (icon);
-  
+
   /* file */
   priv->chooser_image = gtk_file_chooser_button_new (_("Image to burn"), GTK_FILE_CHOOSER_ACTION_OPEN);
   gtk_widget_show (priv->chooser_image);
@@ -180,6 +155,10 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (priv->chooser_image), filter);
   gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (priv->chooser_image), filter);
 
+  if(xfburn_main_has_initial_dir ()) {
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (priv->chooser_image), xfburn_main_get_initial_dir ());
+  }
+
   if (last_file) {
     gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (priv->chooser_image), last_file);
   }
@@ -187,24 +166,24 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   frame = xfce_gtk_frame_box_new_with_content (_("Image to burn"), priv->chooser_image);
   gtk_widget_show (frame);
   gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
-  
+
   /* red label for image */
   priv->image_label = gtk_label_new ("");
   gtk_widget_show (priv->image_label);
   gtk_box_pack_start (GTK_BOX (box), priv->image_label, FALSE, FALSE, 0);
   update_image_label (GTK_FILE_CHOOSER (priv->chooser_image), obj);
   g_signal_connect (G_OBJECT (priv->chooser_image), "selection-changed", G_CALLBACK (update_image_label), obj);
-    
+
   /* devices list */
   priv->device_box = xfburn_device_box_new (SHOW_CD_WRITERS | SHOW_CDRW_WRITERS | SHOW_DVD_WRITERS | SHOW_MODE_SELECTION | SHOW_SPEED_SELECTION);
   gtk_widget_show (priv->device_box);
-  
+
   frame = xfce_gtk_frame_box_new_with_content (_("Burning device"), priv->device_box);
   gtk_widget_show (frame);
   gtk_box_pack_start (box, frame, FALSE, FALSE, BORDER);
 
   /* options */
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_widget_show (vbox);
 
   frame = xfce_gtk_frame_box_new_with_content (_("Options"), vbox);
@@ -236,16 +215,16 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   gtk_box_pack_start (GTK_BOX (vbox), priv->check_quit, FALSE, FALSE, BORDER);
 
   /* action buttons */
-  button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+  button = gtk_button_new_with_mnemonic (_("_Cancel"));
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_CANCEL);
 
-  priv->burn_button = xfburn_gtk_button_new_mixed (XFBURN_STOCK_BURN_CD, _("_Burn image"));
+  priv->burn_button = xfce_gtk_button_new_mixed ("stock_xfburn", _("_Burn image"));
   gtk_widget_show (priv->burn_button);
   g_signal_connect (G_OBJECT (priv->burn_button), "clicked", G_CALLBACK (cb_clicked_ok), obj);
-  gtk_container_add (GTK_CONTAINER( GTK_DIALOG(obj)->action_area), priv->burn_button);
+  gtk_container_add (GTK_CONTAINER( exo_gtk_dialog_get_action_area (GTK_DIALOG (obj))), priv->burn_button);
   //gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS (priv->burn_button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (priv->burn_button, TRUE);
   gtk_widget_grab_focus (priv->burn_button);
   gtk_widget_grab_default (priv->burn_button);
 
@@ -274,7 +253,7 @@ xfburn_burn_image_dialog_finalize (GObject *object)
 /*************/
 /* internals */
 /*************/
-static gboolean 
+static gboolean
 prepare_params (ThreadBurnIsoParams *params, struct burn_drive *drive, gchar **failure_msg)
 {
   struct burn_write_opts * burn_options;
@@ -376,13 +355,13 @@ create_disc (ThreadBurnIsoParams *params, gchar **failure_msg)
     *failure_msg = _("An error occurred in the burn backend");
     return FALSE;
   }
-  
+
   burn_session_add_track (params->session, params->track, BURN_POS_END);
 
   return TRUE;
 }
 
-static void
+static void*
 thread_burn_iso (ThreadBurnIsoParams * params)
 {
   GtkWidget *dialog_progress = params->dialog_progress;
@@ -400,14 +379,14 @@ thread_burn_iso (ThreadBurnIsoParams * params)
 
     // this assumes that an iso image can only have one track
     sectors[0] = burn_disc_get_sectors (params->disc);
-    
+
     xfburn_progress_dialog_set_status_with_text (XFBURN_PROGRESS_DIALOG (dialog_progress), XFBURN_PROGRESS_DIALOG_STATUS_RUNNING, _("Burning image..."));
 
     fifos = g_new(struct burn_source *,1);
     fifos[0] = params->fifo_src;
 
     xfburn_perform_burn_write (dialog_progress, drive_info->drive, params->write_mode, params->burn_options, DATA_BYTES_PER_SECTOR, params->disc, fifos, sectors);
- 
+
     xfburn_device_release (drive_info, params->eject);
   } else {
     xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to grab the drive."));
@@ -417,6 +396,7 @@ thread_burn_iso (ThreadBurnIsoParams * params)
 
   free_params (params);
   g_free (params);
+  return NULL;
 }
 
 /**
@@ -425,7 +405,7 @@ thread_burn_iso (ThreadBurnIsoParams * params)
 void
 burn_image_dialog_error (XfburnBurnImageDialog * dialog, const gchar * msg_error)
 {
-  xfce_dialog_show_error (NULL, NULL, "%s", msg_error); 
+  xfce_dialog_show_error (NULL, NULL, "%s", msg_error);
 }
 
 static void
@@ -459,7 +439,7 @@ cb_dialog_response (XfburnBurnImageDialog * dialog, gint response_id, gpointer u
 
     priv->params->dialog_progress = dialog_progress;
     gtk_widget_show (dialog_progress);
-    
+
     g_thread_new ("burn_iso", (GThreadFunc) thread_burn_iso, priv->params);
   } else {
     xfburn_main_leave_window ();
@@ -473,7 +453,7 @@ update_image_label (GtkFileChooser *chooser, XfburnBurnImageDialog * dialog)
 
   if (gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser)) == NULL) {
     gtk_label_set_markup (GTK_LABEL(priv->image_label),
-                          _("<span weight=\"bold\" foreground=\"darkred\" stretch=\"semiexpanded\">Please select an image to burn</span>"));   
+                          _("<span weight=\"bold\" foreground=\"darkred\" stretch=\"semiexpanded\">Please select an image to burn</span>"));
   } else {
     gtk_label_set_text (GTK_LABEL(priv->image_label), "");
     check_burn_button (dialog);
@@ -499,7 +479,7 @@ check_burn_button (XfburnBurnImageDialog * dialog)
   }
 }
 
-static gboolean 
+static gboolean
 check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct burn_drive *drive)
 {
   enum burn_disc_status disc_state;
@@ -518,7 +498,7 @@ check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct
   } else if (disc_state != BURN_DISC_BLANK) {
     if (disc_state == BURN_DISC_FULL)
       burn_image_dialog_error (dialog, _("Closed disc with data detected. Need blank or appendable disc"));
-    else if (disc_state == BURN_DISC_EMPTY) 
+    else if (disc_state == BURN_DISC_EMPTY)
       burn_image_dialog_error (dialog, _("No disc detected in drive"));
     else {
       burn_image_dialog_error (dialog, _("Cannot recognize state of drive and disc"));
@@ -544,7 +524,7 @@ check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct
   return TRUE;
 }
 
-static void 
+static void
 cb_clicked_ok (GtkButton *button, gpointer user_data)
 {
   XfburnBurnImageDialog * dialog = (XfburnBurnImageDialog *) user_data;
@@ -575,7 +555,7 @@ cb_clicked_ok (GtkButton *button, gpointer user_data)
   device = xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box));
   speed = xfburn_device_box_get_speed (XFBURN_DEVICE_BOX (priv->device_box));
   write_mode = xfburn_device_box_get_mode (XFBURN_DEVICE_BOX (priv->device_box));
-      
+
   params = g_new0 (ThreadBurnIsoParams, 1);
   params->device = device;
   params->iso_path = iso_path;
@@ -585,7 +565,7 @@ cb_clicked_ok (GtkButton *button, gpointer user_data)
   params->dummy = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_dummy));
   params->burnfree = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_burnfree));
   params->stream_recording = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_stream_recording));
-  
+
   if (!xfburn_device_grab (device, &drive_info)) {
     burn_image_dialog_error (dialog, _("Unable to grab the drive."));
 
