@@ -32,7 +32,7 @@
 #include "xfburn-data-composition.h"
 #include "xfburn-audio-composition.h"
 
-#define XFBURN_COMPOSITIONS_NOTEBOOK_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_COMPOSITIONS_NOTEBOOK, XfburnCompositionsNotebookPrivate))
+#define XFBURN_COMPOSITIONS_NOTEBOOK_GET_PRIVATE(obj) (xfburn_compositions_notebook_get_instance_private (obj))
 
 /* private members */
 typedef struct
@@ -42,13 +42,11 @@ typedef struct
 
 
 /* prototypes */
-static void xfburn_compositions_notebook_class_init (XfburnCompositionsNotebookClass * klass);
-static void xfburn_compositions_notebook_init (XfburnCompositionsNotebook * notebook);
 static void xfburn_compositions_notebook_finalize (GObject * object);
 
 
 /* internals */
-static void cb_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, 
+static void cb_switch_page (GtkNotebook *notebook, GtkWidget *page, guint page_num, 
                             XfburnCompositionsNotebookPrivate *priv);
 static void cb_composition_close (XfburnNotebookTab *tab, GtkNotebook *notebook);
 static void cb_composition_name_changed (XfburnComposition *composition, const gchar * name, XfburnCompositionsNotebook *notebook);
@@ -58,38 +56,13 @@ static XfburnComposition * add_composition_with_data (XfburnCompositionsNotebook
 /* static member */
 static GtkNotebookClass *parent_class = NULL;
 
-GType
-xfburn_compositions_notebook_get_type (void)
-{
-  static GType type = 0;
-
-  if (type == 0) {
-    static const GTypeInfo our_info = {
-      sizeof (XfburnCompositionsNotebookClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_compositions_notebook_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnCompositionsNotebook),
-      0,
-      (GInstanceInitFunc) xfburn_compositions_notebook_init,
-      NULL
-    };
-
-    type = g_type_register_static (GTK_TYPE_NOTEBOOK, "XfburnCompositionsNotebook", &our_info, 0);
-  }
-
-  return type;
-}
+G_DEFINE_TYPE_WITH_PRIVATE(XfburnCompositionsNotebook, xfburn_compositions_notebook, GTK_TYPE_NOTEBOOK);
 
 static void
 xfburn_compositions_notebook_class_init (XfburnCompositionsNotebookClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (XfburnCompositionsNotebookPrivate));
-
   parent_class = g_type_class_peek_parent (klass);
   object_class->finalize = xfburn_compositions_notebook_finalize;
 }
@@ -125,7 +98,7 @@ xfburn_compositions_notebook_init (XfburnCompositionsNotebook * notebook)
 /* internals */
 /*************/
 static void
-cb_switch_page (GtkNotebook *notebook, GtkNotebookPage *page, guint page_num, XfburnCompositionsNotebookPrivate *priv)
+cb_switch_page (GtkNotebook *notebook, GtkWidget *page, guint page_num, XfburnCompositionsNotebookPrivate *priv)
 {
 
 }
@@ -226,7 +199,7 @@ xfburn_compositions_notebook_add_composition (XfburnCompositionsNotebook *notebo
 }
 
 void
-xfburn_compositions_notebook_add_welcome_tab (XfburnCompositionsNotebook *notebook, GtkActionGroup *action_group)
+xfburn_compositions_notebook_add_welcome_tab (XfburnCompositionsNotebook *notebook, GActionMap *action_group)
 {
   GtkWidget *welcome_tab = NULL;
   GtkWidget *label;
