@@ -30,11 +30,10 @@
 #include "xfburn-copy-cd-progress-dialog.h"
 #include "xfburn-create-iso-progress-dialog.h"
 #include "xfburn-device-box.h"
-#include "xfburn-stock.h"
 
 #include "xfburn-copy-dvd-dialog.h"
 
-#define XFBURN_COPY_DVD_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_COPY_DVD_DIALOG, XfburnCopyDvdDialogPrivate))
+#define XFBURN_COPY_DVD_DIALOG_GET_PRIVATE(obj) (xfburn_copy_dvd_dialog_get_instance_private (XFBURN_COPY_DVD_DIALOG (obj)))
 
 typedef struct
 {
@@ -50,10 +49,6 @@ typedef struct
   GtkWidget *check_dummy;
 } XfburnCopyDvdDialogPrivate;
 
-/* prototypes */
-static void xfburn_copy_dvd_dialog_class_init (XfburnCopyDvdDialogClass * klass);
-static void xfburn_copy_dvd_dialog_init (XfburnCopyDvdDialog * sp);
-
 static void cb_device_changed (XfburnDeviceBox *box, const gchar *device_name, XfburnCopyDvdDialogPrivate *priv);
 static void cb_check_only_iso_toggled (GtkToggleButton * button, XfburnCopyDvdDialog * dialog);
 static void cb_browse_iso (GtkButton * button, XfburnCopyDvdDialog * dialog);
@@ -64,36 +59,12 @@ static void cb_dialog_response (XfburnCopyDvdDialog * dialog, gint response_id,
 /*********************/
 static XfceTitledDialogClass *parent_class = NULL;
 
-GType
-xfburn_copy_dvd_dialog_get_type (void)
-{
-  static GType type = 0;
-
-  if (type == 0) {
-    static const GTypeInfo our_info = {
-      sizeof (XfburnCopyDvdDialogClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_copy_dvd_dialog_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnCopyDvdDialog),
-      0,
-      (GInstanceInitFunc) xfburn_copy_dvd_dialog_init,
-      NULL
-    };
-
-    type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnCopyDvdDialog", &our_info, 0);
-  }
-
-  return type;
-}
+/* prototypes */
+G_DEFINE_TYPE_WITH_PRIVATE(XfburnCopyDvdDialog, xfburn_copy_dvd_dialog, XFCE_TYPE_TITLED_DIALOG);
 
 static void
 xfburn_copy_dvd_dialog_class_init (XfburnCopyDvdDialogClass * klass)
-{
-  g_type_class_add_private (klass, sizeof (XfburnCopyDvdDialogPrivate));
-  
+{  
   parent_class = g_type_class_peek_parent (klass);
 }
 
@@ -101,7 +72,7 @@ static void
 xfburn_copy_dvd_dialog_init (XfburnCopyDvdDialog * obj)
 {
   XfburnCopyDvdDialogPrivate *priv = XFBURN_COPY_DVD_DIALOG_GET_PRIVATE (obj);
-  GtkBox *box = GTK_BOX (GTK_DIALOG (obj)->vbox);
+  GtkBox *box = GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (obj)));
   GtkWidget *img;
   GdkPixbuf *icon = NULL;
   GtkWidget *frame;
@@ -109,10 +80,12 @@ xfburn_copy_dvd_dialog_init (XfburnCopyDvdDialog * obj)
   GtkWidget *align;
   GtkWidget *button;
   gchar *default_path, *tmp_dir;
+  gint x,y;
 
   gtk_window_set_title (GTK_WINDOW (obj), _("Copy data DVD"));
   gtk_window_set_destroy_with_parent (GTK_WINDOW (obj), TRUE);
-  icon = gtk_widget_render_icon (GTK_WIDGET (obj), XFBURN_STOCK_DATA_COPY, GTK_ICON_SIZE_DIALOG, NULL);
+  gtk_icon_size_lookup (GTK_ICON_SIZE_DIALOG, &x, &y);
+  icon = gtk_icon_theme_load_icon ( gtk_icon_theme_get_default(), "stock_xfburn-data-copy", x, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
   gtk_window_set_icon (GTK_WINDOW (obj), icon);
   g_object_unref (icon);
 
@@ -133,7 +106,7 @@ xfburn_copy_dvd_dialog_init (XfburnCopyDvdDialog * obj)
   gtk_box_pack_start (box, priv->frame_burn, FALSE, FALSE, BORDER);
     
   /* options */
-  vbox = gtk_vbox_new (FALSE, 0);
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
   gtk_widget_show (vbox);
 
   frame = xfce_create_framebox_with_content (_("Options"), vbox);
@@ -163,7 +136,7 @@ xfburn_copy_dvd_dialog_init (XfburnCopyDvdDialog * obj)
   gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, BORDER * 4, 0);
   gtk_widget_show (align);
   gtk_box_pack_start (GTK_BOX (vbox), align, FALSE, FALSE, 0);
-  priv->hbox_iso = gtk_hbox_new (FALSE, 0);
+  priv->hbox_iso = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_widget_show (priv->hbox_iso);
   gtk_container_add (GTK_CONTAINER (align), priv->hbox_iso);
   gtk_widget_set_sensitive (priv->hbox_iso, FALSE);
@@ -177,7 +150,7 @@ xfburn_copy_dvd_dialog_init (XfburnCopyDvdDialog * obj)
   g_free (tmp_dir);
   gtk_box_pack_start (GTK_BOX (priv->hbox_iso), priv->entry_path_iso, FALSE, FALSE, 0);
 
-  img = gtk_image_new_from_stock (GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_SMALL_TOOLBAR);
+  img = gtk_image_new_from_icon_name ("folder", GTK_ICON_SIZE_SMALL_TOOLBAR);
   gtk_widget_show (img);
   button = gtk_button_new ();
   gtk_container_add (GTK_CONTAINER (button), img);
@@ -186,14 +159,14 @@ xfburn_copy_dvd_dialog_init (XfburnCopyDvdDialog * obj)
   g_signal_connect (G_OBJECT (button), "clicked", G_CALLBACK (cb_browse_iso), obj);
 
   /* action buttons */
-  button = gtk_button_new_from_stock (GTK_STOCK_CANCEL);
+  button = gtk_button_new_with_mnemonic (_("_Cancel"));
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_CANCEL);
 
   button = xfce_create_mixed_button ("xfburn-data-copy", _("_Copy DVD"));
   gtk_widget_show (button);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), button, GTK_RESPONSE_OK);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+  gtk_widget_set_can_default (button, GTK_CAN_DEFAULT);
   gtk_widget_grab_focus (button);
   gtk_widget_grab_default (button);
 
