@@ -273,14 +273,6 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
   GdkScreen *screen;
   GtkIconTheme *icon_theme;
 
-  const gchar ui_string[] = "<interface><menu id=\"popup-menu\">"
-    "<section>"
-    "<item><attribute name=\"action\">win.create-dir</attribute><attribute name=\"label\">Create directory</attribute></item>"
-    "</section><section>"
-    "<item><attribute name=\"action\">win.rename-file</attribute><attribute name=\"label\">Rename</attribute></item>"
-    "<item><attribute name=\"action\">win.remove-file</attribute><attribute name=\"label\">Remove</attribute></item>"
-    "</section></menu></interface>";
-
   GtkTargetEntry gte_src[] =  { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, DATA_COMPOSITION_DND_TARGET_INSIDE } };
   GtkTargetEntry gte_dest[] = { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, DATA_COMPOSITION_DND_TARGET_INSIDE },
                                 { "text/uri-list", 0, DATA_COMPOSITION_DND_TARGET_TEXT_URI_LIST },
@@ -308,8 +300,10 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
 
   priv->ui_manager = gtk_builder_new ();
   gtk_builder_set_translation_domain(priv->ui_manager, GETTEXT_PACKAGE);
-  
-  gtk_builder_add_from_string (priv->ui_manager, ui_string, -1, NULL);
+
+  xfce_resource_push_path (XFCE_RESOURCE_DATA, DATADIR);
+  gchar *popup_ui = xfce_resource_lookup (XFCE_RESOURCE_DATA, "xfburn/xfburn-popup-menus.ui");
+  gtk_builder_add_from_file (priv->ui_manager, popup_ui, NULL);
 
   hbox_toolbar = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
   gtk_box_pack_start (GTK_BOX (composition), hbox_toolbar, FALSE, TRUE, 0);
@@ -336,16 +330,16 @@ xfburn_data_composition_init (XfburnDataComposition * composition)
   gtk_widget_insert_action_group (priv->toolbar, "win", G_ACTION_GROUP (priv->action_group));
 
   xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbar),
-    "list-add", "Add", "win.add-file", _("Add the selected file(s) to the composition"));
+    "list-add", _("Add"), "win.add-file", _("Add the selected file(s) to the composition"));
   xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbar),
-    "folder-new", "Create directory", "win.create-dir", _("Add a new directory to the composition"));
+    "folder-new", _("Create directory"), "win.create-dir", _("Add a new directory to the composition"));
 
   gtk_toolbar_insert (GTK_TOOLBAR (priv->toolbar), gtk_separator_tool_item_new(), -1);
 
   xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbar),
-    "list-remove", "Remove", "win.remove-file", _("Remove the selected file(s) from the composition"));
+    "list-remove", _("Remove"), "win.remove-file", _("Remove the selected file(s) from the composition"));
   xfburn_add_button_to_toolbar (GTK_TOOLBAR (priv->toolbar),
-    "edit-clear", "Clear", "win.clear", _("Clear the content of the composition"));
+    "edit-clear", _("Clear"), "win.clear", _("Clear the content of the composition"));
 
   gtk_box_pack_start (GTK_BOX (hbox_toolbar), priv->toolbar, TRUE, TRUE, 0);
   gtk_widget_show_all (priv->toolbar);
@@ -590,10 +584,10 @@ cb_treeview_button_pressed (GtkTreeView * treeview, GdkEventButton * event, Xfbu
       gtk_tree_path_free (path);
     }
 
-    model = G_MENU_MODEL (gtk_builder_get_object (priv->ui_manager, "popup-menu"));
+    model = G_MENU_MODEL (gtk_builder_get_object (priv->ui_manager, "data-popup-menu"));
     menu_popup = gtk_menu_new_from_model (model);
     gtk_widget_insert_action_group(GTK_WIDGET(menu_popup), "win", G_ACTION_GROUP(priv->action_group));
-    
+
     GList *childs = gtk_container_get_children (GTK_CONTAINER (menu_popup));
     menuitem_remove = GTK_WIDGET (childs->next->next->data);
     menuitem_rename = GTK_WIDGET (childs->next->data);
