@@ -31,7 +31,7 @@
 #include "xfburn-blank-dialog.h"
 #include "xfburn-cclosure-marshal.h"
 
-#define XFBURN_DEVICE_BOX_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_DEVICE_BOX, XfburnDeviceBoxPrivate))
+#define XFBURN_DEVICE_BOX_GET_PRIVATE(obj) (xfburn_device_box_get_instance_private (XFBURN_DEVICE_BOX (obj)))
 
 enum {
   PROP_0,
@@ -91,8 +91,6 @@ typedef struct
 } XfburnDeviceBoxPrivate;
 
 /* prototypes */
-static void xfburn_device_box_class_init (XfburnDeviceBoxClass *);
-static GObject * xfburn_device_box_constructor (GType type, guint n_construct_properties, GObjectConstructParam *construct_properties);
 static void xfburn_device_box_finalize (GObject * object);
 static void xfburn_device_box_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static void xfburn_device_box_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
@@ -112,7 +110,7 @@ static void empty_speed_list_dialog (void);
 #endif
 
 /* globals */
-static GtkVBoxClass *parent_class = NULL;
+static GtkBoxClass *parent_class = NULL;
 
 /*************************/
 /* XfburnDeviceBox class */
@@ -120,42 +118,15 @@ static GtkVBoxClass *parent_class = NULL;
 
 static guint signals[LAST_SIGNAL];
 
-GType
-xfburn_device_box_get_type (void)
-{
-  static GType device_box_type = 0;
-
-  if (!device_box_type)
-    {
-      static const GTypeInfo device_box_info = {
-        sizeof (XfburnDeviceBoxClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) xfburn_device_box_class_init,
-        NULL,
-        NULL,
-        sizeof (XfburnDeviceBox),
-        0,
-        NULL,
-        NULL
-      };
-
-      device_box_type = g_type_register_static (GTK_TYPE_VBOX, "XfburnDeviceBox", &device_box_info, 0);
-    }
-
-  return device_box_type;
-}
+G_DEFINE_TYPE_WITH_PRIVATE(XfburnDeviceBox, xfburn_device_box, GTK_TYPE_BOX);
 
 static void
 xfburn_device_box_class_init (XfburnDeviceBoxClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   
-  g_type_class_add_private (klass, sizeof (XfburnDeviceBoxPrivate));
-
   parent_class = g_type_class_peek_parent (klass);
   
-  object_class->constructor  = xfburn_device_box_constructor;
   object_class->finalize     = xfburn_device_box_finalize;
   object_class->set_property = xfburn_device_box_set_property;
   object_class->get_property = xfburn_device_box_get_property;
@@ -187,12 +158,10 @@ xfburn_device_box_class_init (XfburnDeviceBoxClass * klass)
                                                         FALSE, G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 }
 
-static GObject * 
-xfburn_device_box_constructor (GType type, guint n_construct_properties, GObjectConstructParam *construct_properties)
+static void 
+xfburn_device_box_init (XfburnDeviceBox *box)
 {
-  GObject *gobj;
-  XfburnDeviceBox *box;
-  XfburnDeviceBoxPrivate *priv;
+  XfburnDeviceBoxPrivate *priv = xfburn_device_box_get_instance_private(box);
 
   GtkWidget *label;
   //GtkWidget *hbox;
@@ -201,9 +170,7 @@ xfburn_device_box_constructor (GType type, guint n_construct_properties, GObject
   XfburnDeviceList *devlist;
   gint n_burners;
   
-  gobj = G_OBJECT_CLASS (parent_class)->constructor (type, n_construct_properties, construct_properties);
-  box = XFBURN_DEVICE_BOX (gobj);
-  priv = XFBURN_DEVICE_BOX_GET_PRIVATE (box);
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (box), GTK_ORIENTATION_VERTICAL);
 
   priv->devlist = devlist = xfburn_device_list_new ();
   priv->handler_volume_change_start = g_signal_connect (G_OBJECT (devlist), "volume-change-start", G_CALLBACK (cb_volume_change_start), box);
@@ -214,13 +181,13 @@ xfburn_device_box_constructor (GType type, guint n_construct_properties, GObject
   gtk_box_pack_start (GTK_BOX (box), priv->combo_device, FALSE, FALSE, BORDER);
   
   /*
-  hbox = gtk_hbox_new (FALSE, 0);
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_widget_show (hbox);
   gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, BORDER);
   */
 
   /* disc label */
-  priv->hbox_refresh = gtk_hbox_new (FALSE, 0);
+  priv->hbox_refresh = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_widget_show (priv->hbox_refresh);
   gtk_box_pack_start (GTK_BOX (box), priv->hbox_refresh, TRUE, TRUE, BORDER);
 
@@ -232,7 +199,7 @@ xfburn_device_box_constructor (GType type, guint n_construct_properties, GObject
   gtk_box_pack_start (GTK_BOX (priv->hbox_refresh), xfburn_device_list_get_refresh_button (devlist), FALSE, FALSE, BORDER);
 
   /* speed */
-  priv->hbox_speed_selection = gtk_hbox_new (FALSE, 0);
+  priv->hbox_speed_selection = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_widget_show (priv->hbox_speed_selection);
   gtk_box_pack_start (GTK_BOX (box), priv->hbox_speed_selection, TRUE, TRUE, BORDER);
 
@@ -255,7 +222,7 @@ xfburn_device_box_constructor (GType type, guint n_construct_properties, GObject
   }
 
   /* mode */
-  priv->hbox_mode_selection = gtk_hbox_new (FALSE, 0);
+  priv->hbox_mode_selection = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
   gtk_widget_show (priv->hbox_mode_selection);
   gtk_box_pack_start (GTK_BOX (box), priv->hbox_mode_selection, FALSE, FALSE, BORDER);
 
@@ -289,8 +256,6 @@ xfburn_device_box_constructor (GType type, guint n_construct_properties, GObject
   priv->have_asked_for_blanking = FALSE;
 
   refresh_drive_info (box, xfburn_device_list_get_current_device (priv->devlist));
-
-  return gobj;
 }
 
 static void
@@ -375,7 +340,7 @@ empty_speed_list_dialog (void)
   dialog = (GtkDialog *) gtk_dialog_new_with_buttons (_("Empty speed list"),
                                   NULL,
                                   GTK_DIALOG_DESTROY_WITH_PARENT,
-                                  GTK_STOCK_CLOSE,
+                                  "window-close",
                                   GTK_RESPONSE_CLOSE,
                                   NULL);
 
@@ -480,7 +445,7 @@ status_label_update (XfburnDeviceBoxPrivate *priv)
   gchar * text;
   gboolean sensitive;
 
-  sensitive = GTK_WIDGET_SENSITIVE (priv->combo_device);
+  sensitive = gtk_widget_get_sensitive (priv->combo_device);
 
   //DBG ("sensitive = %d", sensitive);
 
@@ -493,6 +458,7 @@ status_label_update (XfburnDeviceBoxPrivate *priv)
   g_free (text);
 }
 
+
 static gboolean
 ask_for_blanking (XfburnDeviceBoxPrivate *priv)
 {
@@ -713,7 +679,7 @@ fill_combo_mode (XfburnDeviceBox *box, XfburnDevice *device)
 static void
 cb_volume_change_start (XfburnDeviceList *devlist, gboolean device_changed, XfburnDeviceBox *box)
 {
-  if (GTK_WIDGET_REALIZED (box))
+  if (gtk_widget_get_realized (GTK_WIDGET(box)))
     xfburn_busy_cursor (GTK_WIDGET (box));
 }
 
@@ -728,7 +694,7 @@ cb_volume_change_end (XfburnDeviceList *devlist, gboolean device_changed, Xfburn
 
   refresh_drive_info (box, device);
 
-  if (GTK_WIDGET_REALIZED (box))
+  if (gtk_widget_get_realized (GTK_WIDGET (box)))
     xfburn_default_cursor (GTK_WIDGET (box));
 
   g_signal_emit (box, signals[VOLUME_CHANGED], 0, device_changed, device);
