@@ -32,7 +32,7 @@
 #include "xfburn-directory-browser.h"
 #include "xfburn-main.h"
 
-#define XFBURN_FILE_BROWSER_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_FILE_BROWSER, XfburnFileBrowserPrivate))
+#define XFBURN_FILE_BROWSER_GET_PRIVATE(obj) (xfburn_file_browser_get_instance_private (obj))
 
 typedef enum {
   FS_BROWSER,
@@ -45,8 +45,6 @@ typedef struct {
 } XfburnFileBrowserPrivate;
 
 /* prototypes */
-static void xfburn_file_browser_class_init (XfburnFileBrowserClass *);
-static void xfburn_file_browser_init (XfburnFileBrowser *);
 
 static void cb_fs_browser_selection_changed (GtkTreeSelection *, XfburnFileBrowser *);
 static void cb_directory_browser_row_activated (GtkWidget *, GtkTreePath *, GtkTreeViewColumn *, XfburnFileBrowser *);
@@ -55,38 +53,13 @@ static gboolean cb_focus_in_event (GtkWidget *widget, GdkEventFocus *event, Xfbu
 /***************************/
 /* XfburnFileBrowser class */
 /***************************/
-static GtkHPanedClass *parent_class = NULL;
+static GtkPanedClass *parent_class = NULL;
 
-GType
-xfburn_file_browser_get_type (void)
-{
-  static GType file_browser_type = 0;
-
-  if (!file_browser_type) {
-    static const GTypeInfo file_browser_info = {
-      sizeof (XfburnFileBrowserClass),
-      NULL,
-      NULL,
-      (GClassInitFunc) xfburn_file_browser_class_init,
-      NULL,
-      NULL,
-      sizeof (XfburnFileBrowser),
-      0,
-      (GInstanceInitFunc) xfburn_file_browser_init,
-      NULL
-    };
-
-    file_browser_type = g_type_register_static (GTK_TYPE_HPANED, "XfburnFileBrowser", &file_browser_info, 0);
-  }
-
-  return file_browser_type;
-}
+G_DEFINE_TYPE_WITH_PRIVATE(XfburnFileBrowser, xfburn_file_browser, GTK_TYPE_PANED);
 
 static void
 xfburn_file_browser_class_init (XfburnFileBrowserClass * klass)
 {
-  g_type_class_add_private (klass, sizeof (XfburnFileBrowserPrivate));
-  
   parent_class = g_type_class_peek_parent (klass);
 }
 
@@ -96,6 +69,8 @@ xfburn_file_browser_init (XfburnFileBrowser * file_browser)
   GtkWidget *scrolled_window;
   GtkTreeSelection *selection;
 
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (file_browser), GTK_ORIENTATION_HORIZONTAL);
+
   /* FS browser */
   scrolled_window = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
@@ -157,8 +132,7 @@ cb_directory_browser_row_activated (GtkWidget * treeview, GtkTreePath * path, Gt
     gtk_tree_model_get_iter (model_dir, &iter_dir, path_dir);
     gtk_tree_model_get (model_dir, &iter_dir, DIRECTORY_BROWSER_COLUMN_FILE, &directory, -1);
 
-    g_list_foreach (selected_row, (GFunc) gtk_tree_path_free, NULL);
-    g_list_free (selected_row);
+    g_list_free_full (selected_row, (GDestroyNotify) gtk_tree_path_free);
 
     /* expand the parent directory in the FS browser */
     path_fs = gtk_tree_model_get_path (model_fs, &iter_fs);
