@@ -30,10 +30,12 @@
 #include "xfburn-data-composition.h"
 #include "xfburn-utils.h"
 #include "xfburn-settings.h"
+#include "xfburn-main.h"
+
 
 /* prototypes */
-static void xfburn_fs_browser_class_init (XfburnFsBrowserClass * klass);
-static void xfburn_fs_browser_init (XfburnFsBrowser * sp);
+static void xfburn_fs_browser_class_init (XfburnFsBrowserClass * klass, gpointer data);
+static void xfburn_fs_browser_init (XfburnFsBrowser * sp, gpointer data);
 
 static void cb_browser_row_expanded (GtkTreeView *, GtkTreeIter *, GtkTreePath *, gpointer);
 static void cb_browser_row_activated (GtkTreeView *tree_view, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data);
@@ -70,13 +72,13 @@ xfburn_fs_browser_get_type (void)
 }
 
 static void
-xfburn_fs_browser_class_init (XfburnFsBrowserClass * klass)
+xfburn_fs_browser_class_init (XfburnFsBrowserClass * klass, gpointer data)
 {
   parent_class = g_type_class_peek_parent (klass);
 }
 
 static void
-xfburn_fs_browser_init (XfburnFsBrowser * browser)
+xfburn_fs_browser_init (XfburnFsBrowser * browser, gpointer data)
 {
   GtkTreeStore *model;
   GtkTreeViewColumn *column_directory;
@@ -88,7 +90,7 @@ xfburn_fs_browser_init (XfburnFsBrowser * browser)
   model = gtk_tree_store_new (FS_BROWSER_N_COLUMNS, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_STRING);
   gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), FS_BROWSER_COLUMN_DIRECTORY, GTK_SORT_ASCENDING);
   gtk_tree_view_set_model (GTK_TREE_VIEW (browser), GTK_TREE_MODEL (model));
-  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (browser), TRUE);
+  // gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (browser), TRUE);
 
   column_directory = gtk_tree_view_column_new ();
   gtk_tree_view_column_set_title (column_directory, _("Filesystem"));
@@ -110,7 +112,7 @@ xfburn_fs_browser_init (XfburnFsBrowser * browser)
 
   g_signal_connect (G_OBJECT (browser), "row-expanded", G_CALLBACK (cb_browser_row_expanded), browser);
   g_signal_connect (G_OBJECT (browser), "row-activated", G_CALLBACK (cb_browser_row_activated), browser);
-  
+
   /* load the directory list */
   xfburn_fs_browser_refresh (browser);
 
@@ -146,7 +148,7 @@ load_directory_in_browser (XfburnFsBrowser * browser, const gchar * path, GtkTre
 
   screen = gtk_widget_get_screen (GTK_WIDGET (browser));
   icon_theme = gtk_icon_theme_get_for_screen (screen);
-  icon = gtk_icon_theme_load_icon (icon_theme, "gnome-fs-directory", x, 0, NULL);
+  icon = gtk_icon_theme_load_icon (icon_theme, "folder", x, 0, NULL);
 
   show_hidden = xfburn_settings_get_boolean ("show-hidden-files", FALSE);
 
@@ -225,7 +227,7 @@ cb_browser_drag_data_get (GtkWidget * widget, GdkDragContext * dc,
 {
   if (info == DATA_COMPOSITION_DND_TARGET_TEXT_PLAIN) {
     gchar *full_path = NULL;
-    
+
     full_path = xfburn_fs_browser_get_selection (browser);
     gtk_selection_data_set_text (data, full_path, -1);
     g_free (full_path);
@@ -243,7 +245,7 @@ void
 xfburn_fs_browser_refresh (XfburnFsBrowser * browser)
 {
   GtkTreeModel *model;
-  GtkTreeIter iter_home, iter_root;
+  GtkTreeIter iter_initial, iter_home, iter_root;
   int x, y;
   gchar *text;
   GdkScreen *screen;
@@ -258,11 +260,31 @@ xfburn_fs_browser_refresh (XfburnFsBrowser * browser)
 
   gtk_icon_size_lookup (GTK_ICON_SIZE_SMALL_TOOLBAR, &x, &y);
 
+  /* load the initial dir, if set */
+  if (xfburn_main_has_initial_dir ()) {
+    text = g_path_get_basename (xfburn_main_get_initial_dir ());
+
+    screen = gtk_widget_get_screen (GTK_WIDGET (browser));
+    icon_theme = gtk_icon_theme_get_for_screen (screen);
+    icon = gtk_icon_theme_load_icon (icon_theme, "gnome-fs-directory", x, 0, NULL);
+
+    gtk_tree_store_append (GTK_TREE_STORE (model), &iter_initial, NULL);
+    gtk_tree_store_set (GTK_TREE_STORE (model), &iter_initial,
+                        FS_BROWSER_COLUMN_ICON, icon,
+                        FS_BROWSER_COLUMN_DIRECTORY, text, FS_BROWSER_COLUMN_PATH, xfburn_main_get_initial_dir (), -1);
+    if (icon)
+      g_object_unref (icon);
+    g_free (text);
+
+    load_directory_in_browser (browser, xfburn_main_get_initial_dir (), &iter_initial);
+  }
+
+
   /* load the user's home dir */
   text = g_strdup_printf (_("%s's home"), g_get_user_name ());
 
   screen = gtk_widget_get_screen (GTK_WIDGET (browser));
-  icon_theme = gtk_icon_theme_get_for_screen (screen);  
+  icon_theme = gtk_icon_theme_get_for_screen (screen);
   icon = gtk_icon_theme_load_icon (icon_theme, "gnome-fs-home", x, 0, NULL);
 
   gtk_tree_store_append (GTK_TREE_STORE (model), &iter_home, NULL);
@@ -288,10 +310,19 @@ xfburn_fs_browser_refresh (XfburnFsBrowser * browser)
 
   /* set cursor on home dir row */
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (browser));
-  gtk_tree_selection_select_iter (selection, &iter_home);
+  if (xfburn_main_has_initial_dir ()) {
+    /* set cursor on initial dir row */
+    gtk_tree_selection_select_iter (selection, &iter_initial);
 
-  /* expand the home dir row */
-  path = gtk_tree_model_get_path (model, &iter_home);
+    /* expand the initial dir row */
+    path = gtk_tree_model_get_path (model, &iter_initial);
+  } else {
+    /* set cursor on home dir row */
+    gtk_tree_selection_select_iter (selection, &iter_home);
+
+    /* expand the home dir row */
+    path = gtk_tree_model_get_path (model, &iter_home);
+  }
   gtk_tree_view_expand_row (GTK_TREE_VIEW (browser), path, FALSE);
   gtk_tree_path_free (path);
 }
@@ -308,12 +339,12 @@ xfburn_fs_browser_get_selection (XfburnFsBrowser *browser)
   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (browser));
   if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
     gchar *path = NULL;
-   
+
     gtk_tree_model_get (model, &iter, FS_BROWSER_COLUMN_PATH, &path, -1);
 
     full_path = g_strdup_printf ("file://%s", path);
     g_free (path);
   }
-  
+
   return full_path;
 }
