@@ -37,7 +37,7 @@
 #include "xfburn-main.h"
 #include "xfburn-utils.h"
 
-#define XFBURN_PROGRESS_DIALOG_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), XFBURN_TYPE_PROGRESS_DIALOG, XfburnProgressDialogPrivate))
+#define XFBURN_PROGRESS_DIALOG_GET_PRIVATE(obj) (xfburn_progress_dialog_get_instance_private (XFBURN_PROGRESS_DIALOG (obj)))
 
 enum {
   BURNING_DONE,
@@ -165,7 +165,7 @@ xfburn_progress_dialog_init (XfburnProgressDialog * obj)
   gtk_window_set_default_size (GTK_WINDOW (obj), 575, 200);
 
   /* label */
-  priv->label_action = gtk_label_new ("Initializing ...");
+  priv->label_action = gtk_label_new (_("Initializing..."));
   gtk_label_set_xalign(GTK_LABEL (priv->label_action), 0.1);
   gtk_label_set_justify (GTK_LABEL (priv->label_action), GTK_JUSTIFY_LEFT);
   gtk_label_set_selectable (GTK_LABEL (priv->label_action), TRUE);
@@ -224,7 +224,7 @@ xfburn_progress_dialog_init (XfburnProgressDialog * obj)
   g_signal_connect (G_OBJECT (priv->button_stop), "clicked", G_CALLBACK (cb_button_stop_clicked), obj);
 
   priv->button_close = gtk_button_new_from_icon_name ("gtk-close", GTK_ICON_SIZE_BUTTON);
-  gtk_button_set_label (GTK_BUTTON (priv->button_close), "Close");
+  gtk_button_set_label (GTK_BUTTON (priv->button_close), _("Close"));
   gtk_widget_show (priv->button_close);
   gtk_dialog_add_action_widget (GTK_DIALOG (obj), priv->button_close, GTK_RESPONSE_CLOSE);
   gtk_widget_set_can_default (priv->button_close, TRUE);
