@@ -48,4 +48,7 @@ void xfburn_capture_libburn_messages (void);
 void xfburn_console_libburn_messages (void);
 int xfburn_media_profile_to_kb (int media_no);
 
+void xfburn_add_button_to_toolbar(GtkToolbar *toolbar, const gchar *stock, const gchar *text, const gchar *action, const gchar *tooltip);
+GtkWidget * xfburn_create_progress_bar(const gchar *);
+
 #endif
